package com.yijia.customer.mapper;

import java.util.List;
import com.yijia.customer.domain.CustomerGradeSetting;

/**
 * 客户优惠等级设置Mapper接口
 *
 * @author yijia
 * @date 2021-01-08
 */
public interface CustomerGradeSettingMapper
{
    /**
     * 查询客户优惠等级设置
     *
     * @param id 客户优惠等级设置ID
     * @return 客户优惠等级设置
     */
    public CustomerGradeSetting selectCustomerGradeSettingById(Long id);

    /**
     * 查询客户优惠等级设置列表
     *
     * @param customerGradeSetting 客户优惠等级设置
     * @return 客户优惠等级设置集合
     */
    public List<CustomerGradeSetting> customerGradeSettingMapper(CustomerGradeSetting customerGradeSetting);

    /**
     * 新增客户优惠等级设置
     *
     * @param customerGradeSetting 客户优惠等级设置
     * @return 结果
     */
    public int insertCustomerGradeSetting(CustomerGradeSetting customerGradeSetting);

    /**
     * 修改客户优惠等级设置
     *
     * @param customerGradeSetting 客户优惠等级设置
     * @return 结果
     */
    public int updateCustomerGradeSetting(CustomerGradeSetting customerGradeSetting);

    /**
     * 删除客户优惠等级设置
     *
     * @param id 客户优惠等级设置ID
     * @return 结果
     */
    public int deleteCustomerGradeSettingById(Long id);

    /**
     * 批量删除客户优惠等级设置
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCustomerGradeSettingByIds(Long[] ids);

    public List<CustomerGradeSetting> selectCustomerGradeSettingList(CustomerGradeSetting customerGradeSetting);
}
